pub struct EventQueue { /* private fields */ }Expand description
Async mpsc-based ordered event queue.
Inputs are processed strictly in the order they arrive.
Implementations
Sourceimpl EventQueue
impl EventQueue
Sourcepub fn new() -> (Self, EventQueueHandle)
pub fn new() -> (Self, EventQueueHandle)
Create a new event queue, returning both the queue (consumer) and a cloneable handle (producer).